@@ -3,6 +3,7 @@
  * MATE Power Manager Brightness Applet
  * Copyright (C) 2006 Benjamin Canou <bookeldor@gmail.com>
  * Copyright (C) 2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -35,7 +36,6 @@
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
 
-#include "egg-debug.h"
 #include "gpm-common.h"
 
 #define GPM_TYPE_BRIGHTNESS_APPLET		(gpm_brightness_applet_get_type ())
@@ -128,7 +128,7 @@ gpm_applet_get_brightness (GpmBrightnessApplet *applet)
 	guint policy_brightness;
 
 	if (applet->proxy == NULL) {
-		egg_warning ("not connected\n");
+		g_warning ("not connected\n");
 		return FALSE;
 	}
 
@@ -137,14 +137,14 @@ gpm_applet_get_brightness (GpmBrightnessApplet *applet)
 				 G_TYPE_UINT, &policy_brightness,
 				 G_TYPE_INVALID);
 	if (error) {
-		egg_debug ("ERROR: %s\n", error->message);
+		g_debug ("ERROR: %s\n", error->message);
 		g_error_free (error);
 	}
 	if (ret) {
 		applet->level = policy_brightness;
 	} else {
 		/* abort as the DBUS method failed */
-		egg_warning ("GetBrightness failed!\n");
+		g_warning ("GetBrightness failed!\n");
 	}
 
 	return ret;
@@ -161,7 +161,7 @@ gpm_applet_set_brightness (GpmBrightnessApplet *applet)
 	gboolean ret;
 
 	if (applet->proxy == NULL) {
-		egg_warning ("not connected");
+		g_warning ("not connected");
 		return FALSE;
 	}
 
@@ -170,12 +170,12 @@ gpm_applet_set_brightness (GpmBrightnessApplet *applet)
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (error) {
-		egg_debug ("ERROR: %s", error->message);
+		g_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
 	if (!ret) {
 		/* abort as the DBUS method failed */
-		egg_warning ("SetBrightness failed!");
+		g_warning ("SetBrightness failed!");
 	}
 
 	return ret;
@@ -215,9 +215,9 @@ gpm_applet_get_icon (GpmBrightnessApplet *applet)
 						 icon, applet->size - 2, 0, NULL);
 
 	if (applet->icon == NULL) {
-		egg_warning ("Cannot find %s!\n", icon);
+		g_warning ("Cannot find %s!\n", icon);
 	} else {
-		egg_debug ("got icon %s!\n", icon);
+		g_debug ("got icon %s!\n", icon);
 		/* update size cache */
 		applet->icon_height = gdk_pixbuf_get_height (applet->icon);
 		applet->icon_width = gdk_pixbuf_get_width (applet->icon);
@@ -299,7 +299,7 @@ gpm_applet_draw_cb (GpmBrightnessApplet *applet)
 		cairo_rectangle (cr, 0, 0, w, h);
 		cairo_fill (cr);
 	}
-	
+
 	/* draw color background */
 	if (bg_type == PANEL_COLOR_BACKGROUND && !applet->popped) {
 		gdk_cairo_set_source_rgba (cr, &color);
@@ -489,7 +489,7 @@ static gboolean
 gpm_applet_key_press_cb (GtkWidget *popup, GdkEventKey *event, GpmBrightnessApplet *applet)
 {
 	int i;
-	
+
 	switch (event->keyval) {
 	case GDK_KEY_KP_Enter:
 	case GDK_KEY_ISO_Enter:
@@ -557,7 +557,7 @@ gpm_applet_scroll_cb (GpmBrightnessApplet *applet, GdkEventScroll *event)
 			for (i = 0;i < 5;i++) {
 				gpm_applet_plus_cb (NULL, applet);
 			}
-			
+
 		} else {
 			for (i = 0;i < 5;i++) {
 				gpm_applet_minus_cb (NULL, applet);
@@ -841,7 +841,7 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 	                       "title", _("About Power Manager Brightness Applet"),
 	                       "comments", GPM_BRIGHTNESS_APPLET_DESC,
 	                       "copyright", _("Copyright \xC2\xA9 2006 Benjamin Canou\n"
-	                                      "Copyright \xC2\xA9 2011-2020 MATE developers"),
+	                                      "Copyright \xC2\xA9 2011-2021 MATE developers"),
 	                       "icon-name", GPM_BRIGHTNESS_APPLET_ICON,
 	                       "logo-icon-name", GPM_BRIGHTNESS_APPLET_ICON,
 	                       "license", license_trans,
@@ -849,7 +849,7 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 	                       "documenters", documenters,
 	                       "translator-credits", _("translator-credits"),
 	                       "wrap-license", TRUE,
-	                       "website", "https://mate-desktop.org",
+	                       "website", PACKAGE_URL,
 	                       NULL);
 
 	g_free (license_trans);
@@ -900,7 +900,7 @@ brightness_changed_cb (DBusGProxy          *proxy,
 		       guint	            brightness,
 		       GpmBrightnessApplet *applet)
 {
-	egg_debug ("BrightnessChanged detected: %i\n", brightness);
+	g_debug ("BrightnessChanged detected: %i\n", brightness);
 	applet->level = brightness;
 }
 
@@ -913,18 +913,18 @@ gpm_brightness_applet_dbus_connect (GpmBrightnessApplet *applet)
 	GError *error = NULL;
 
 	if (applet->connection == NULL) {
-		egg_debug ("get connection\n");
+		g_debug ("get connection\n");
 		g_clear_error (&error);
 		applet->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 		if (error != NULL) {
-			egg_warning ("Could not connect to DBUS daemon: %s", error->message);
+			g_warning ("Could not connect to DBUS daemon: %s", error->message);
 			g_error_free (error);
 			applet->connection = NULL;
 			return FALSE;
 		}
 	}
 	if (applet->proxy == NULL) {
-		egg_debug ("get proxy\n");
+		g_debug ("get proxy\n");
 		g_clear_error (&error);
 		applet->proxy = dbus_g_proxy_new_for_name_owner (applet->connection,
 							 GPM_DBUS_SERVICE,
@@ -932,7 +932,7 @@ gpm_brightness_applet_dbus_connect (GpmBrightnessApplet *applet)
 							 GPM_DBUS_INTERFACE_BACKLIGHT,
 							 &error);
 		if (error != NULL) {
-			egg_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
+			g_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
 			g_error_free (error);
 			applet->proxy = NULL;
 			return FALSE;
@@ -955,7 +955,7 @@ gboolean
 gpm_brightness_applet_dbus_disconnect (GpmBrightnessApplet *applet)
 {
 	if (applet->proxy != NULL) {
-		egg_debug ("removing proxy\n");
+		g_debug ("removing proxy\n");
 		g_object_unref (applet->proxy);
 		applet->proxy = NULL;
 	}
@@ -996,8 +996,6 @@ gpm_brightness_applet_name_vanished_cb (GDBusConnection *connection,
 static void
 gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 {
-	DBusGConnection *connection;
-
 	/* initialize fields */
 	applet->size = 0;
 	applet->call_worked = TRUE;
@@ -1078,7 +1076,6 @@ gpm_applet_cb (MatePanelApplet *_applet, const gchar *iid, gpointer data)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(_applet);
 	GtkActionGroup *action_group;
-	gchar *ui_path;
 
 	static const GtkActionEntry menu_actions [] = {
 		{ "About", "help-about", N_("_About"),
@@ -1099,9 +1096,9 @@ gpm_applet_cb (MatePanelApplet *_applet, const gchar *iid, gpointer data)
 				      menu_actions,
 				      G_N_ELEMENTS (menu_actions),
 				      applet);
-	ui_path = g_build_filename (BRIGHTNESS_MENU_UI_DIR, "brightness-applet-menu.xml", NULL);
-	mate_panel_applet_setup_menu_from_file (MATE_PANEL_APPLET (applet), ui_path, action_group);
-	g_free (ui_path);
+	mate_panel_applet_setup_menu_from_file (MATE_PANEL_APPLET (applet),
+	                                        BRIGHTNESS_MENU_UI_DIR "/brightness-applet-menu.xml",
+	                                        action_group);
 	g_object_unref (action_group);
 
 	gpm_applet_draw_cb (applet);
