@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -27,7 +28,6 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
-#include "egg-debug.h"
 #include "gpm-common.h"
 
 /**
@@ -45,11 +45,7 @@ gpm_help_display (const gchar *link_id)
 	else
 		uri = g_strdup ("help:mate-power-manager");
 
-#if GTK_CHECK_VERSION (3, 22, 0)
 	gtk_show_uri_on_window (NULL, uri, GDK_CURRENT_TIME, &error);
-#else
-	gtk_show_uri (NULL, uri, GDK_CURRENT_TIME, &error);
-#endif
 
 	if (error != NULL) {
 		GtkWidget *d;
