@@ -3,6 +3,7 @@
  * MATE Power Manager Inhibit Applet
  * Copyright (C) 2006 Benjamin Canou <bookeldor@gmail.com>
  * Copyright (C) 2006-2009 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -34,7 +35,6 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 
-#include "egg-debug.h"
 #include "gpm-common.h"
 
 #define GPM_TYPE_INHIBIT_APPLET		(gpm_inhibit_applet_get_type ())
@@ -103,7 +103,7 @@ gpm_applet_inhibit (GpmInhibitApplet *applet,
 	g_return_val_if_fail (cookie != NULL, FALSE);
 
 	if (applet->proxy == NULL) {
-		egg_warning ("not connected\n");
+		g_warning ("not connected\n");
 		return FALSE;
 	}
 
@@ -136,7 +136,7 @@ gpm_applet_uninhibit (GpmInhibitApplet *applet,
 	gboolean ret;
 
 	if (applet->proxy == NULL) {
-		egg_warning ("not connected");
+		g_warning ("not connected");
 		return FALSE;
 	}
 
@@ -310,7 +310,7 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 	                       "title", _("About Power Manager Inhibit Applet"),
 	                       "comments", GPM_INHIBIT_APPLET_DESC,
 	                       "copyright", _("Copyright \xC2\xA9 2006-2007 Richard Hughes\n"
-	                                      "Copyright \xC2\xA9 2011-2020 MATE developers"),
+	                                      "Copyright \xC2\xA9 2011-2021 MATE developers"),
 	                       "icon-name", GPM_INHIBIT_APPLET_ICON_INHIBIT,
 	                       "logo-icon-name", GPM_INHIBIT_APPLET_ICON_INHIBIT,
 	                       "license", license_trans,
@@ -318,7 +318,7 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 	                       "documenters", documenters,
 	                       "translator-credits", _("translator-credits"),
 	                       "wrap-license", TRUE,
-	                       "website", "https://mate-desktop.org",
+	                       "website", PACKAGE_URL,
 	                       NULL);
 
 	g_free (license_trans);
@@ -367,18 +367,18 @@ gpm_inhibit_applet_dbus_connect (GpmInhibitApplet *applet)
 	GError *error = NULL;
 
 	if (applet->connection == NULL) {
-		egg_debug ("get connection\n");
+		g_debug ("get connection\n");
 		g_clear_error (&error);
 		applet->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 		if (error != NULL) {
-			egg_warning ("Could not connect to DBUS daemon: %s", error->message);
+			g_warning ("Could not connect to DBUS daemon: %s", error->message);
 			g_error_free (error);
 			applet->connection = NULL;
 			return FALSE;
 		}
 	}
 	if (applet->proxy == NULL) {
-		egg_debug ("get proxy\n");
+		g_debug ("get proxy\n");
 		g_clear_error (&error);
 		applet->proxy = dbus_g_proxy_new_for_name_owner (applet->connection,
 							 GS_DBUS_SERVICE,
@@ -386,7 +386,7 @@ gpm_inhibit_applet_dbus_connect (GpmInhibitApplet *applet)
 							 GS_DBUS_INTERFACE,
 							 &error);
 		if (error != NULL) {
-			egg_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
+			g_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
 			g_error_free (error);
 			applet->proxy = NULL;
 			return FALSE;
@@ -402,7 +402,7 @@ gboolean
 gpm_inhibit_applet_dbus_disconnect (GpmInhibitApplet *applet)
 {
 	if (applet->proxy != NULL) {
-		egg_debug ("removing proxy\n");
+		g_debug ("removing proxy\n");
 		g_object_unref (applet->proxy);
 		applet->proxy = NULL;
 		/* we have no inhibit, these are not persistent across reboots */
@@ -445,8 +445,6 @@ gpm_inhibit_applet_name_vanished_cb (GDBusConnection *connection,
 static void
 gpm_inhibit_applet_init (GpmInhibitApplet *applet)
 {
-	DBusGConnection *connection;
-
 	/* initialize fields */
 	applet->image = NULL;
 	applet->cookie = 0;
@@ -500,7 +498,6 @@ gpm_applet_cb (MatePanelApplet *_applet, const gchar *iid, gpointer data)
 {
 	GpmInhibitApplet *applet = GPM_INHIBIT_APPLET(_applet);
 	GtkActionGroup *action_group;
-	gchar *ui_path;
 
 	static const GtkActionEntry menu_actions [] = {
 		{ "About", "help-about", N_("_About"),
@@ -521,9 +518,9 @@ gpm_applet_cb (MatePanelApplet *_applet, const gchar *iid, gpointer data)
 				      menu_actions,
 				      G_N_ELEMENTS (menu_actions),
 				      applet);
-	ui_path = g_build_filename (INHIBIT_MENU_UI_DIR, "inhibit-applet-menu.xml", NULL);
-	mate_panel_applet_setup_menu_from_file (MATE_PANEL_APPLET (applet), ui_path, action_group);
-	g_free (ui_path);
+	mate_panel_applet_setup_menu_from_file (MATE_PANEL_APPLET (applet),
+	                                        INHIBIT_MENU_UI_DIR "/inhibit-applet-menu.xml",
+	                                        action_group);
 	g_object_unref (action_group);
 
 	return TRUE;
