@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -161,9 +162,8 @@ guint        gpm_discrete_from_percent          (guint percentage,
 guint        gpm_discrete_to_percent            (guint discrete,
                                                  guint levels);
 void         gpm_help_display                   (const gchar    *link_id);
-gboolean     gpm_dialog_page_scroll_event_cb    (GtkWidget      *widget,
-                                                 GdkEventScroll *event,
-                                                 GtkWindow      *window);
+gboolean     gpm_notebook_scroll_event_cb       (GtkWidget      *widget,
+                                                 GdkEventScroll *event);
 #ifdef EGG_TEST
 void         gpm_common_test                     (gpointer data);
 #endif
