@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -39,11 +40,13 @@
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 
+#ifdef WITH_LIBSECRET
+#include <libsecret/secret.h>
+#endif /* WITH_LIBSECRET */
 #ifdef WITH_KEYRING
 #include <gnome-keyring.h>
 #endif /* WITH_KEYRING */
 
-#include "egg-debug.h"
 #include "egg-console-kit.h"
 
 #include "gpm-screensaver.h"
@@ -93,7 +96,7 @@ gpm_control_systemd_shutdown (void) {
 	GDBusProxy *proxy;
 	GVariant *res = NULL;
 
-	egg_debug ("Requesting systemd to shutdown");
+	g_debug ("Requesting systemd to shutdown");
 	proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
 					       G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
 					       NULL,
@@ -104,7 +107,7 @@ gpm_control_systemd_shutdown (void) {
 					       &error );
 	//append all our arguments
 	if (proxy == NULL) {
-		egg_error("Error connecting to dbus - %s", error->message);
+		g_warning ("Error connecting to dbus - %s", error->message);
 		g_error_free (error);
 		return FALSE;
 	}
@@ -117,7 +120,7 @@ gpm_control_systemd_shutdown (void) {
 				      &error
 				      );
 	if (error != NULL) {
-		egg_error ("Error in dbus - %s", error->message);
+		g_warning ("Error in dbus - %s", error->message);
 		g_error_free (error);
 		return FALSE;
 	}
@@ -189,11 +192,11 @@ gpm_control_get_lock_policy (GpmControl *control, const gchar *policy)
 		GSettings *settings_ss;
 		settings_ss = g_settings_new (GS_SETTINGS_SCHEMA);
 		do_lock = g_settings_get_boolean (settings_ss, GS_SETTINGS_PREF_LOCK_ENABLED);
-		egg_debug ("Using ScreenSaver settings (%i)", do_lock);
+		g_debug ("Using ScreenSaver settings (%i)", do_lock);
 		g_object_unref (settings_ss);
 	} else {
 		do_lock = g_settings_get_boolean (control->priv->settings, policy);
-		egg_debug ("Using custom locking settings (%i)", do_lock);
+		g_debug ("Using custom locking settings (%i)", do_lock);
 	}
 	return do_lock;
 }
@@ -211,6 +214,13 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	EggConsoleKit *console;
 	GpmScreensaver *screensaver;
 	guint32 throttle_cookie = 0;
+#ifdef WITH_LIBSECRET
+	gboolean lock_libsecret;
+	GCancellable *libsecret_cancellable = NULL;
+	SecretService *secretservice_proxy = NULL;
+	gint num_secrets_locked;
+	GList *libsecret_collections = NULL;
+#endif /* WITH_LIBSECRET */
 #ifdef WITH_KEYRING
 	gboolean lock_gnome_keyring;
 	GnomeKeyringResult keyres;
@@ -228,19 +238,49 @@ gpm_control_suspend (GpmControl *control, GError **error)
 		g_object_unref (console);
 
 		if (!allowed) {
-			egg_debug ("cannot suspend as not allowed from policy");
+			g_debug ("cannot suspend as not allowed from policy");
 			g_set_error_literal (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot suspend");
 			goto out;
 		}
 	}
 
+#ifdef WITH_LIBSECRET
+	/* we should perhaps lock keyrings when sleeping #375681 */
+	lock_libsecret = g_settings_get_boolean (control->priv->settings,
+						 GPM_SETTINGS_LOCK_KEYRING_SUSPEND);
+	if (lock_libsecret) {
+		libsecret_cancellable = g_cancellable_new ();
+		secretservice_proxy = secret_service_get_sync (SECRET_SERVICE_LOAD_COLLECTIONS,
+							       libsecret_cancellable,
+							       error);
+		if (secretservice_proxy == NULL) {
+			g_warning ("failed to connect to secret service");
+		} else {
+			libsecret_collections = secret_service_get_collections (secretservice_proxy);
+			if ( libsecret_collections == NULL) {
+				g_warning ("failed to get secret collections");
+			} else {
+				num_secrets_locked = secret_service_lock_sync (secretservice_proxy,
+									       libsecret_collections,
+									       libsecret_cancellable,
+									       NULL,
+									       error);
+				if (num_secrets_locked <= 0)
+					g_warning ("could not lock keyring");
+				g_list_free (libsecret_collections);
+			}
+			g_object_unref (secretservice_proxy);
+		}
+		g_object_unref (libsecret_cancellable);
+	}
+#endif /* WITH_LIBSECRET */
 #ifdef WITH_KEYRING
 	/* we should perhaps lock keyrings when sleeping #375681 */
 	lock_gnome_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_SUSPEND);
 	if (lock_gnome_keyring) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK)
-			egg_warning ("could not lock keyring");
+			g_warning ("could not lock keyring");
 	}
 #endif /* WITH_KEYRING */
 
@@ -255,7 +295,7 @@ gpm_control_suspend (GpmControl *control, GError **error)
 		gpm_networkmanager_sleep ();
 
 	/* Do the suspend */
-	egg_debug ("emitting sleep");
+	g_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_SUSPEND);
 
 	if (LOGIND_RUNNING()) {
@@ -269,7 +309,7 @@ gpm_control_suspend (GpmControl *control, GError **error)
 						       NULL,
 						       &dbus_error );
 		if (proxy == NULL) {
-			egg_error("Error connecting to dbus - %s", dbus_error->message);
+			g_warning ("Error connecting to dbus - %s", dbus_error->message);
 			g_error_free (dbus_error);
 			ret = FALSE;
 			goto out;
@@ -282,7 +322,7 @@ gpm_control_suspend (GpmControl *control, GError **error)
 					      &dbus_error
 					      );
 		if (dbus_error != NULL ) {
-			egg_debug ("Error in dbus - %s", dbus_error->message);
+			g_warning ("Error in dbus - %s", dbus_error->message);
 			g_error_free (dbus_error);
 			ret = TRUE;
 		}
@@ -298,7 +338,7 @@ gpm_control_suspend (GpmControl *control, GError **error)
 		g_object_unref (console);
 	}
 
-	egg_debug ("emitting resume");
+	g_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
 
 	if (do_lock) {
@@ -329,6 +369,13 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	EggConsoleKit *console;
 	GpmScreensaver *screensaver;
 	guint32 throttle_cookie = 0;
+#ifdef WITH_LIBSECRET
+	gboolean lock_libsecret;
+	GCancellable *libsecret_cancellable = NULL;
+	SecretService *secretservice_proxy = NULL;
+	gint num_secrets_locked;
+	GList *libsecret_collections = NULL;
+#endif /* WITH_LIBSECRET */
 #ifdef WITH_KEYRING
 	gboolean lock_gnome_keyring;
 	GnomeKeyringResult keyres;
@@ -346,19 +393,49 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 		g_object_unref (console);
 
 		if (!allowed) {
-			egg_debug ("cannot hibernate as not allowed from policy");
+			g_debug ("cannot hibernate as not allowed from policy");
 			g_set_error_literal (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot hibernate");
 			goto out;
 		}
 	}
 
+#ifdef WITH_LIBSECRET
+	/* we should perhaps lock keyrings when sleeping #375681 */
+	lock_libsecret = g_settings_get_boolean (control->priv->settings,
+						 GPM_SETTINGS_LOCK_KEYRING_SUSPEND);
+	if (lock_libsecret) {
+		libsecret_cancellable = g_cancellable_new ();
+		secretservice_proxy = secret_service_get_sync (SECRET_SERVICE_LOAD_COLLECTIONS,
+							       libsecret_cancellable,
+							       error);
+		if (secretservice_proxy == NULL) {
+			g_warning ("failed to connect to secret service");
+		} else {
+			libsecret_collections = secret_service_get_collections (secretservice_proxy);
+			if ( libsecret_collections == NULL) {
+				g_warning ("failed to get secret collections");
+			} else {
+				num_secrets_locked = secret_service_lock_sync (secretservice_proxy,
+									       libsecret_collections,
+									       libsecret_cancellable,
+									       NULL,
+									       error);
+				if (num_secrets_locked <= 0)
+					g_warning ("could not lock keyring");
+				g_list_free (libsecret_collections);
+			}
+			g_object_unref (secretservice_proxy);
+		}
+		g_object_unref (libsecret_cancellable);
+	}
+#endif /* WITH_LIBSECRET */
 #ifdef WITH_KEYRING
 	/* we should perhaps lock keyrings when sleeping #375681 */
 	lock_gnome_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_HIBERNATE);
 	if (lock_gnome_keyring) {
 		keyres = gnome_keyring_lock_all_sync ();
 		if (keyres != GNOME_KEYRING_RESULT_OK) {
-			egg_warning ("could not lock keyring");
+			g_warning ("could not lock keyring");
 		}
 	}
 #endif /* WITH_KEYRING */
@@ -373,7 +450,7 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	if (nm_sleep)
 		gpm_networkmanager_sleep ();
 
-	egg_debug ("emitting sleep");
+	g_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
 	if (LOGIND_RUNNING()) {
@@ -387,7 +464,7 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 						       NULL,
 						       &dbus_error );
 		if (proxy == NULL) {
-			egg_error("Error connecting to dbus - %s", dbus_error->message);
+			g_warning ("Error connecting to dbus - %s", dbus_error->message);
 			g_error_free (dbus_error);
 			ret = FALSE;
 			goto out;
@@ -400,7 +477,7 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 					      &dbus_error
 					      );
 		if (dbus_error != NULL ) {
-			egg_debug ("Error in dbus - %s", dbus_error->message);
+			g_warning ("Error in dbus - %s", dbus_error->message);
 			g_error_free (dbus_error);
 			ret = TRUE;
 		}
@@ -415,7 +492,7 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 		g_object_unref (console);
 	}
 
-	egg_debug ("emitting resume");
+	g_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
 	if (do_lock) {
