@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2010 Alex Launi <alex launi canonical com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -24,7 +25,6 @@
 #include <libupower-glib/upower.h>
 #include <gtk/gtk.h>
 
-#include "egg-debug.h"
 #include "gpm-button.h"
 #include "gpm-common.h"
 #include "gpm-control.h"
@@ -139,16 +139,16 @@ gpm_kbd_backlight_set (GpmKbdBacklight *backlight,
                    NULL,
                    NULL);
    }
-    egg_debug("Set brightness to %i", backlight->priv->brightness);
+   g_debug("Set brightness to %i", backlight->priv->brightness);
    return TRUE;
 }
 
-/** 
+/**
  * gpm_kbd_backlight_dialog_init
  **/
 static void
-gpm_kbd_backlight_dialog_init (GpmKbdBacklight *backlight) 
-{  
+gpm_kbd_backlight_dialog_init (GpmKbdBacklight *backlight)
+{
     if (backlight->priv->popup != NULL
 	    && !msd_osd_window_is_valid (MSD_OSD_WINDOW (backlight->priv->popup))) {
 		gtk_widget_destroy (backlight->priv->popup);
@@ -325,106 +325,6 @@ gpm_kbd_backlight_on_dbus_signal (GDBusProxy *proxy,
    g_debug ("signal '%s' not handled!", signal_name);
 }
 
-/**
- * gpm_kbd_backlight_dbus_method_call:
- * @connection:
- * @object_path:
- * @interface_name:
- * @method_name:
- * @parameters:
- * @invocation:
- * @user_data:
- **/
-static void
-gpm_kbd_backlight_dbus_method_call (GDBusConnection *connection,
-                   const gchar *sender,
-                   const gchar *object_path,
-                   const gchar *interface_name,
-                   const gchar *method_name,
-                   GVariant *parameters,
-                   GDBusMethodInvocation *invocation,
-                   gpointer user_data)
-{
-   guint value;
-   gboolean ret;
-   GError *error = NULL;
-   GpmKbdBacklight *backlight = GPM_KBD_BACKLIGHT (user_data);
-
-   if (g_strcmp0 (method_name, "GetBrightness") == 0) {
-       ret = gpm_kbd_backlight_get_brightness (backlight, &value, &error);
-       if (!ret) {
-           g_dbus_method_invocation_return_gerror (invocation, error);
-           g_error_free (error);
-       } else {
-           g_dbus_method_invocation_return_value (invocation, g_variant_new ("(u)", value));
-       }
-       return;
-   }
-
-   if (g_strcmp0 (method_name, "SetBrightness") == 0) {
-       g_variant_get (parameters, "(u)", &value);
-       ret = gpm_kbd_backlight_set_brightness (backlight, value, &error);
-       if (!ret) {
-           g_dbus_method_invocation_return_gerror (invocation, error);
-           g_error_free (error);
-       } else {
-           g_dbus_method_invocation_return_value (invocation, NULL);
-       }
-       return;
-   }
-
-   g_assert_not_reached ();
-}
-
-
-/**
- * gpm_kbd_backlight_dbus_property_get:
- * @sender:
- * @object_path:
- * @interface_name:
- * @property_name:
- * @error:
- * @user_data:
- *
- * Return value:
- **/
-static GVariant *
-gpm_kbd_backlight_dbus_property_get (GDBusConnection *connection,
-                    const gchar *sender,
-                    const gchar *object_path,
-                    const gchar *interface_name,
-                    const gchar *property_name,
-                    GError **error,
-                    gpointer user_data)
-{
-   /* Do nothing, we have no props */
-   return NULL;
-}
-
-/**
- * gpm_kbd_backlight_dbus_property_set:
- * @connection:
- * @sender:
- * @object_path:
- * @interface_name:
- * @property_name:
- *
- * Return value:
- **/
-static gboolean
-gpm_kbd_backlight_dbus_property_set (GDBusConnection *connection,
-                    const gchar *sender,
-                    const gchar *object_path,
-                        const gchar *interface_name,
-                        const gchar *property_name,
-                    GVariant *value,
-                    GError **error,
-                    gpointer user_data)
-{
-   /* do nothing, no properties defined */
-   return FALSE;
-}
-
 static gboolean
 gpm_kbd_backlight_evaluate_power_source_and_set (GpmKbdBacklight *backlight)
 {
@@ -523,9 +423,9 @@ gpm_kbd_backlight_button_pressed_cb (GpmButton *button,
 
    if (g_strcmp0 (type, GPM_BUTTON_KBD_BRIGHT_UP) == 0) {
        ret = gpm_kbd_backlight_brightness_up (backlight);
-        
+
         if (ret) {
-            egg_debug("Going to display OSD");
+            g_debug("Going to display OSD");
             gpm_kbd_backlight_dialog_init (backlight);
 			msd_media_keys_window_set_volume_level (MSD_MEDIA_KEYS_WINDOW (backlight->priv->popup), backlight->priv->brightness_percent);
             gpm_kbd_backlight_dialog_show (backlight);
@@ -535,12 +435,12 @@ gpm_kbd_backlight_button_pressed_cb (GpmButton *button,
        ret = gpm_kbd_backlight_brightness_down (backlight);
 
         if (ret) {
-            egg_debug("Going to display OSD");
+            g_debug("Going to display OSD");
             gpm_kbd_backlight_dialog_init (backlight);
 			msd_media_keys_window_set_volume_level (MSD_MEDIA_KEYS_WINDOW (backlight->priv->popup), backlight->priv->brightness_percent);
             gpm_kbd_backlight_dialog_show (backlight);
         }
-        
+
    } else if (g_strcmp0 (type, GPM_BUTTON_KBD_BRIGHT_TOGGLE) == 0) {
        if (backlight->priv->master_percentage == 0) {
            /* backlight is off turn it back on */
@@ -576,7 +476,7 @@ gpm_kbd_backlight_idle_changed_cb (GpmIdle *idle,
    gboolean on_battery;
    gboolean enable_action;
 
-    egg_debug("Idle changed");
+   g_debug("Idle changed");
 
    lid_closed = gpm_button_is_lid_closed (backlight->priv->button);
 
@@ -597,16 +497,16 @@ gpm_kbd_backlight_idle_changed_cb (GpmIdle *idle,
        return;
 
    if (mode == GPM_IDLE_MODE_NORMAL) {
-        egg_debug("GPM_IDLE_MODE_NORMAL");
+       g_debug ("GPM_IDLE_MODE_NORMAL");
        backlight->priv->master_percentage = 100;
        gpm_kbd_backlight_evaluate_power_source_and_set (backlight);
    } else if (mode == GPM_IDLE_MODE_DIM) {
-       egg_debug("GPM_IDLE_MODE_DIM");
+       g_debug ("GPM_IDLE_MODE_DIM");
        brightness = backlight->priv->master_percentage;
        value = g_settings_get_int (backlight->priv->settings, GPM_SETTINGS_KBD_BRIGHTNESS_DIM_BY_ON_IDLE);
 
        if (value > 100) {
-           egg_warning ("Cannot scale brightness down by more than 100%%. Scaling by 50%%");
+           g_warning ("Cannot scale brightness down by more than 100%%. Scaling by 50%%");
            value = 50;
        }
 
