@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2007-2008 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -28,7 +29,6 @@
 #include <dbus/dbus-glib.h>
 
 #include "gpm-phone.h"
-#include "egg-debug.h"
 #include "gpm-marshal.h"
 
 static void     gpm_phone_finalize   (GObject	    *object);
@@ -40,7 +40,7 @@ struct GpmPhonePrivate
 	guint			 watch_id;
 	gboolean		 present;
 	guint			 percentage;
-	gboolean		 onac;	 
+	gboolean		 onac;
 };
 
 enum {
@@ -69,14 +69,14 @@ gpm_phone_coldplug (GpmPhone *phone)
 	g_return_val_if_fail (GPM_IS_PHONE (phone), FALSE);
 
 	if (phone->priv->proxy == NULL) {
-		egg_warning ("not connected");
+		g_debug ("Phone is not connected");
 		return FALSE;
 	}
 
 	ret = dbus_g_proxy_call (phone->priv->proxy, "Coldplug", &error,
 				 G_TYPE_INVALID, G_TYPE_INVALID);
 	if (error != NULL) {
-		egg_warning ("DEBUG: ERROR: %s", error->message);
+		g_warning ("DEBUG: ERROR: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -141,11 +141,11 @@ gpm_phone_battery_state_changed (DBusGProxy *proxy, guint idx, guint percentage,
 {
 	g_return_if_fail (GPM_IS_PHONE (phone));
 
-	egg_debug ("got BatteryStateChanged %i = %i (%i)", idx, percentage, on_ac);
+	g_debug ("got BatteryStateChanged %i = %i (%i)", idx, percentage, on_ac);
 	phone->priv->percentage = percentage;
 	phone->priv->onac = on_ac;
 	phone->priv->present = TRUE;
-	egg_debug ("emitting device-refresh : (%i)", idx);
+	g_debug ("emitting device-refresh : (%i)", idx);
 	g_signal_emit (phone, signals [DEVICE_REFRESH], 0, idx);
 }
 
@@ -156,9 +156,9 @@ gpm_phone_num_batteries_changed (DBusGProxy *proxy, guint number, GpmPhone *phon
 {
 	g_return_if_fail (GPM_IS_PHONE (phone));
 
-	egg_debug ("got NumberBatteriesChanged %i", number);
+	g_debug ("got NumberBatteriesChanged %i", number);
 	if (number > 1) {
-		egg_warning ("number not 0 or 1, not valid!");
+		g_warning ("number not 0 or 1, not valid!");
 		return;
 	}
 
@@ -167,13 +167,13 @@ gpm_phone_num_batteries_changed (DBusGProxy *proxy, guint number, GpmPhone *phon
 		phone->priv->present = FALSE;
 		phone->priv->percentage = 0;
 		phone->priv->onac = FALSE;
-		egg_debug ("emitting device-removed : (%i)", 0);
+		g_debug ("emitting device-removed : (%i)", 0);
 		g_signal_emit (phone, signals [DEVICE_REMOVED], 0, 0);
 		return;
 	}
 
 	if (phone->priv->present) {
-		egg_warning ("duplicate NumberBatteriesChanged with no change");
+		g_warning ("duplicate NumberBatteriesChanged with no change");
 		return;
 	}
 
@@ -181,7 +181,7 @@ gpm_phone_num_batteries_changed (DBusGProxy *proxy, guint number, GpmPhone *phon
 	phone->priv->present = TRUE;
 	phone->priv->percentage = 0;
 	phone->priv->onac = FALSE;
-	egg_debug ("emitting device-added : (%i)", 0);
+	g_debug ("emitting device-added : (%i)", 0);
 	g_signal_emit (phone, signals [DEVICE_ADDED], 0, 0);
 }
 
@@ -233,18 +233,18 @@ gpm_phone_service_appeared_cb (GDBusConnection *connection,
 	g_return_if_fail (GPM_IS_PHONE (phone));
 
 	if (phone->priv->connection == NULL) {
-		egg_debug ("get connection");
+		g_debug ("get connection");
 		g_clear_error (&error);
 		phone->priv->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 		if (error != NULL) {
-			egg_warning ("Could not connect to DBUS daemon: %s", error->message);
+			g_warning ("Could not connect to DBUS daemon: %s", error->message);
 			g_error_free (error);
 			phone->priv->connection = NULL;
 			return;
 		}
 	}
 	if (phone->priv->proxy == NULL) {
-		egg_debug ("get proxy");
+		g_debug ("get proxy");
 		g_clear_error (&error);
 		phone->priv->proxy = dbus_g_proxy_new_for_name_owner (phone->priv->connection,
 							 MATE_PHONE_MANAGER_DBUS_SERVICE,
@@ -252,7 +252,7 @@ gpm_phone_service_appeared_cb (GDBusConnection *connection,
 							 MATE_PHONE_MANAGER_DBUS_INTERFACE,
 							 &error);
 		if (error != NULL) {
-			egg_warning ("Cannot connect, maybe the daemon is not running: %s", error->message);
+			g_warning ("Cannot connect, maybe the daemon is not running: %s", error->message);
 			g_error_free (error);
 			phone->priv->proxy = NULL;
 			return;
@@ -291,13 +291,13 @@ gpm_phone_service_vanished_cb (GDBusConnection *connection,
 	g_return_if_fail (GPM_IS_PHONE (phone));
 
 	if (phone->priv->proxy != NULL) {
-		egg_debug ("removing proxy");
+		g_debug ("removing proxy");
 		g_object_unref (phone->priv->proxy);
 		phone->priv->proxy = NULL;
 		if (phone->priv->present) {
 			phone->priv->present = FALSE;
 			phone->priv->percentage = 0;
-			egg_debug ("emitting device-removed : (%i)", 0);
+			g_debug ("emitting device-removed : (%i)", 0);
 			g_signal_emit (phone, signals [DEVICE_REMOVED], 0, 0);
 		}
 	}
